pub struct AtRestFlags(/* private fields */);Expand description
Bitflags type for transaction header at-rest flags.
Implementations
Sourceimpl AtRestFlags
impl AtRestFlags
Sourcepub const USE_V2_WIRE_FORMAT: AtRestFlags
pub const USE_V2_WIRE_FORMAT: AtRestFlags
Indicates that the V2 wire format should be used instead of the V1 wire format. This includes the following RFCs:
- Efficient envelopes
- Inlining small values in FIDL envelopes
Sourceimpl AtRestFlags
impl AtRestFlags
Sourcepub const fn empty() -> AtRestFlags
pub const fn empty() -> AtRestFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> AtRestFlags
pub const fn all() -> AtRestFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<AtRestFlags>
pub const fn from_bits(bits: u16) -> Option<AtRestFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> AtRestFlags
pub const fn from_bits_truncate(bits: u16) -> AtRestFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> AtRestFlags
pub const fn from_bits_retain(bits: u16) -> AtRestFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AtRestFlags>
pub fn from_name(name: &str) -> Option<AtRestFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AtRestFlags) -> bool
pub const fn intersects(&self, other: AtRestFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: AtRestFlags) -> bool
pub const fn contains(&self, other: AtRestFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: AtRestFlags)
pub fn insert(&mut self, other: AtRestFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: AtRestFlags)
pub fn remove(&mut self, other: AtRestFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AtRestFlags)
pub fn toggle(&mut self, other: AtRestFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: AtRestFlags, value: bool)
pub fn set(&mut self, other: AtRestFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AtRestFlags) -> AtRestFlags
pub const fn intersection(self, other: AtRestFlags) -> AtRestFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: AtRestFlags) -> AtRestFlags
pub const fn union(self, other: AtRestFlags) -> AtRestFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: AtRestFlags) -> AtRestFlags
pub const fn difference(self, other: AtRestFlags) -> AtRestFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: AtRestFlags) -> AtRestFlags
pub const fn symmetric_difference(self, other: AtRestFlags) -> AtRestFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> AtRestFlags
pub const fn complement(self) -> AtRestFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AtRestFlags
impl AtRestFlags
Sourcepub const fn iter(&self) -> Iter<AtRestFlags> ⓘ
pub const fn iter(&self) -> Iter<AtRestFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AtRestFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<AtRestFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.