pub trait ControlHandle {
// Required methods
fn shutdown(&self);
fn shutdown_with_epitaph(&self, status: Status);
fn is_closed(&self) -> bool;
fn on_closed(&self) -> OnSignals<'_, Unowned<'_, NullableHandle>> ⓘ;
fn signal_peer(
&self,
clear_mask: Signals,
set_mask: Signals,
) -> Result<(), Status>;
}Expand description
A type associated with a RequestStream that can be used to send FIDL
events or to shut down the request stream.
Required Methods
Sourcefn shutdown(&self)
fn shutdown(&self)
Set the server to shutdown. The underlying channel is only closed the next time the stream is polled.
Sourcefn shutdown_with_epitaph(&self, status: Status)
fn shutdown_with_epitaph(&self, status: Status)
Sets the server to shutdown with an epitaph. The underlying channel is only closed the next time the stream is polled.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".