_

Trait _ 

pub trait _: Sized {
    type Service: ServiceMarker<Proxy = Self>;
}
Proxy by which a client sends messages to a FIDL service.

Required Associated Types

type Service: ServiceMarker<Proxy = Self>

The FIDL service this proxy represents.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

h4 class="code-header">type Service: ServiceMarker<Request = Self>

The FIDL service for which this request is destined.

Required Methods

fn dispatch(name: &str, channel: Channel) -> Self

Dispatches a connection attempt to this FIDL service’s member protocol identified by name, producing an instance of this trait.

fn member_names() -> &'static [&'static str]

Returns an array of the service members’ names.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors