pub struct SocketOpts(/* private fields */);Implementations
Sourceimpl SocketOpts
impl SocketOpts
pub const STREAM: SocketOpts
pub const DATAGRAM: SocketOpts
Sourceimpl SocketOpts
impl SocketOpts
Sourcepub const fn empty() -> SocketOpts
pub const fn empty() -> SocketOpts
Get a flags value with all bits unset.
Sourcepub const fn all() -> SocketOpts
pub const fn all() -> SocketOpts
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SocketOpts>
pub const fn from_bits(bits: u32) -> Option<SocketOpts>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SocketOpts
pub const fn from_bits_truncate(bits: u32) -> SocketOpts
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SocketOpts
pub const fn from_bits_retain(bits: u32) -> SocketOpts
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SocketOpts>
pub fn from_name(name: &str) -> Option<SocketOpts>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SocketOpts) -> bool
pub const fn intersects(&self, other: SocketOpts) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SocketOpts) -> bool
pub const fn contains(&self, other: SocketOpts) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SocketOpts)
pub fn insert(&mut self, other: SocketOpts)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SocketOpts)
pub fn remove(&mut self, other: SocketOpts)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SocketOpts)
pub fn toggle(&mut self, other: SocketOpts)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SocketOpts, value: bool)
pub fn set(&mut self, other: SocketOpts, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SocketOpts) -> SocketOpts
pub const fn intersection(self, other: SocketOpts) -> SocketOpts
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SocketOpts) -> SocketOpts
pub const fn union(self, other: SocketOpts) -> SocketOpts
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SocketOpts) -> SocketOpts
pub const fn difference(self, other: SocketOpts) -> SocketOpts
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SocketOpts) -> SocketOpts
pub const fn symmetric_difference(self, other: SocketOpts) -> SocketOpts
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SocketOpts
pub const fn complement(self) -> SocketOpts
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SocketOpts
impl SocketOpts
Sourcepub const fn iter(&self) -> Iter<SocketOpts> ⓘ
pub const fn iter(&self) -> Iter<SocketOpts> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SocketOpts> ⓘ
pub const fn iter_names(&self) -> IterNames<SocketOpts> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.