pub trait ServiceRequest:
Sized
+ Send
+ Sync {
type Service: ServiceMarker<Request = Self>;
// Required methods
fn dispatch(name: &str, channel: Channel) -> Self;
fn member_names() -> &'static [&'static str];
}Expand description
A request to initiate a connection to a FIDL service.
Required Associated Types
Sourcetype Service: ServiceMarker<Request = Self>
type Service: ServiceMarker<Request = Self>
The FIDL service for which this request is destined.
Required Methods
Sourcefn dispatch(name: &str, channel: Channel) -> Self
fn dispatch(name: &str, channel: Channel) -> Self
Dispatches a connection attempt to this FIDL service’s member protocol
identified by name, producing an instance of this trait.
Sourcefn member_names() -> &'static [&'static str]
fn member_names() -> &'static [&'static str]
Returns an array of the service members’ names.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".